@@ -15,11 +15,13 @@ subroutine cluster_denoise(n, obsImg, bandwidth, mmt2, mmt4, &
 
   implicit none
 
-  integer :: n, i, j, k, i1, j1, s, n1clust, n2clust, sl, su, &
-       nitem, l1, l2, locsm, nnghb, bandwidth
+  integer :: n, bandwidth
 
-  double precision :: z(0:600, 0:600), mmt2, small, varnum, &
-       z1(0:600, 0:600), ra, w00, w20, ttemp1, ttemp2, ker, temp, &
+  integer :: i, j, k, i1, j1, s, n1clust, n2clust, sl, su, &
+       nitem, l1, l2, locsm, nnghb
+
+  double precision :: z(0:n, 0:n), mmt2, small, varnum, &
+       z1(0:(n+2*bandwidth), 0:(n+2*bandwidth)), ra, w00, w20, ttemp1, ttemp2, ker, temp, &
        ahat, bhat, chat, obsImg(0:n, 0:n), e, zbar,z1bar, z2bar, &
        varden, sd, z1ss, z2ss, zascend(1:1000), bwr(1:1000), &
        bwrLocalMax, cutoff, ttemp, fhat, mmt4, estImg(0:n, 0:n), zq
@@ -43,7 +45,7 @@ subroutine cluster_denoise(n, obsImg, bandwidth, mmt2, mmt4, &
 
   !! Extend to avoid boundary problems.
 
-  call extend(n, k, z, z1)
+  call extend(n, k, z, z1(0:(n+2*k), 0:(n+2*k)))
 
   !! The following quantities are used in the conventional
   !! local linear CIRCULARLY SYMMETRIC kernel smoothing in
